@@ -30,6 +30,7 @@
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
+#define HAVE_FCNTL_DIRECT 1
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
@@ -72,6 +73,7 @@
 #define HAVE_SYS_IOCTL_H 1
 /* #undef HAVE_SYS_MALLOC_H */
 #define HAVE_SYS_MMAN_H 1
+/* #undef HAVE_SYS_MNTENT_H */
 /* #undef HAVE_SYS_NDIR_H */
 /* #undef HAVE_SYS_PTE_H */
 /* #undef HAVE_SYS_PTEM_H */
@@ -232,7 +234,6 @@
 #define HAVE_STRTOUL 1
 #define HAVE_STRTOULL 1
 /* #undef HAVE_TELL */
-/* #undef HAVE_THR_SETCONCURRENCY */
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
@@ -499,6 +500,7 @@
 #define HAVE_COMPRESS 1
 #define HAVE_EncryptAes128Ctr 1
 #define HAVE_EncryptAes128Gcm 1
+#define HAVE_hkdf 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -530,17 +532,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 11
-#define MYSQL_VERSION_MINOR 2
+#define MYSQL_VERSION_MINOR 3
 #define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 11.2.2"
+#define PACKAGE_STRING "MySQL Server 11.3.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "11.2.2"
-#define VERSION "11.2.2"
+#define PACKAGE_VERSION "11.3.2"
+#define VERSION "11.3.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
